@@ -1,5 +1,6 @@
 /*
  *  Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
+ *  Copyright (C) 2004 Free Software Foundation
  *
  *  This file is part of GNUTLS.
  *
@@ -37,7 +38,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "1.1.2"
+#define LIBGNUTLS_VERSION "1.1.3"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -121,7 +122,6 @@ typedef enum gnutls_handshake_description { GNUTLS_HANDSHAKE_HELLO_REQUEST,
 /* Note that the status bits have different meanings
  * in openpgp keys and x.509 certificate verification.
  */
-#define GNUTLS_CERT_NOT_TRUSTED GNUTLS_CERT_INVALID
 typedef enum gnutls_certificate_status { 
 	GNUTLS_CERT_INVALID=2, /* will be set if the certificate
 				* was not verified.
@@ -145,7 +145,8 @@ typedef enum gnutls_openpgp_key_status { GNUTLS_OPENPGP_KEY,
 
 typedef enum gnutls_close_request { GNUTLS_SHUT_RDWR=0, GNUTLS_SHUT_WR=1 } gnutls_close_request;
 
-typedef enum gnutls_protocol_version { GNUTLS_SSL3=1, GNUTLS_TLS1 } gnutls_protocol_version;
+typedef enum gnutls_protocol_version { GNUTLS_SSL3=1, GNUTLS_TLS1,
+	GNUTLS_TLS1_1 } gnutls_protocol_version;
 
 typedef enum gnutls_certificate_type { GNUTLS_CRT_X509=1, GNUTLS_CRT_OPENPGP 
 } gnutls_certificate_type;
@@ -227,8 +228,6 @@ void gnutls_handshake_set_private_extensions(gnutls_session session, int allow);
 gnutls_handshake_description gnutls_handshake_get_last_out( gnutls_session session);
 gnutls_handshake_description gnutls_handshake_get_last_in( gnutls_session session);
 
-void gnutls_record_set_cbc_protection(gnutls_session session, int prot);
-
 /* Record layer functions.
  */
 ssize_t gnutls_record_send( gnutls_session session, const void *data, size_t sizeofdata);
@@ -497,16 +496,10 @@ typedef enum gnutls_x509_subject_alt_name {
  * callbacks.
  */
 typedef int gnutls_certificate_client_select_function(gnutls_session,
-						      const gnutls_datum *
-						      client_cert,
-						      int ncerts,
-						      const gnutls_datum *
-						      req_ca_cert,
-						      int nreqs);
+      const gnutls_datum * client_cert, int ncerts,
+      const gnutls_datum * req_ca_cert, int nreqs);
 typedef int gnutls_certificate_server_select_function(gnutls_session,
-						      const gnutls_datum *
-						      server_certs,
-						      int ncerts);
+      const gnutls_datum * server_certs, int ncerts);
 
 
 struct gnutls_openpgp_key_int;
@@ -521,23 +514,22 @@ typedef struct gnutls_retr_st {
 		gnutls_x509_crt *x509;
 		gnutls_openpgp_key pgp;
 	} cert;
-	uint ncerts;		/* one for pgp keys */
+	unsigned int ncerts;		/* one for pgp keys */
 
 	union key {
 		gnutls_x509_privkey x509;
 		gnutls_openpgp_privkey pgp;
 	} key;
 
-	uint deinit_all;	/* if non zero all keys will be deinited */
+	unsigned int deinit_all;	/* if non zero all keys will be deinited */
 } gnutls_retr_st;
 
 typedef int gnutls_certificate_client_retrieve_function(gnutls_session,
-							const gnutls_datum
-							* req_ca_rdn,
-							int nreqs,
-							gnutls_retr_st *);
+	const gnutls_datum* req_ca_rdn, int nreqs,
+	const gnutls_pk_algorithm* pk_algos, int pk_algos_length,
+	gnutls_retr_st *);
 typedef int gnutls_certificate_server_retrieve_function(gnutls_session,
-							gnutls_retr_st *);
+	gnutls_retr_st *);
 
 
 /* Functions that allow AUTH_INFO structures handling
@@ -558,42 +550,34 @@ int gnutls_rsa_export_get_modulus_bits(gnutls_session session);
 /* X509PKI */
 
 void gnutls_certificate_client_set_select_function(gnutls_session,
-						   gnutls_certificate_client_select_function
-						   *);
+	gnutls_certificate_client_select_function *);
 void gnutls_certificate_server_set_select_function(gnutls_session,
-						   gnutls_certificate_server_select_function
-						   *);
+	gnutls_certificate_server_select_function *);
 
 /* These are set on the credentials structure.
  */
 void gnutls_certificate_client_set_retrieve_function(gnutls_certificate_client_credentials,
-						     gnutls_certificate_client_retrieve_function
-						     *);
+	gnutls_certificate_client_retrieve_function *);
 void gnutls_certificate_server_set_retrieve_function(gnutls_certificate_server_credentials,
-						     gnutls_certificate_server_retrieve_function
-						     *);
+	gnutls_certificate_server_retrieve_function *);
 
 void gnutls_certificate_server_set_request(gnutls_session,
-					   gnutls_certificate_request);
+	gnutls_certificate_request);
 
 /* X.509 certificate handling functions 
  */
 
 int gnutls_pkcs3_extract_dh_params(const gnutls_datum * params,
-				   gnutls_x509_crt_fmt format,
-				   gnutls_datum * prime,
-				   gnutls_datum * generator,
-				   int *prime_bits);
+	gnutls_x509_crt_fmt format, gnutls_datum * prime,
+	gnutls_datum * generator, int *prime_bits);
 int gnutls_pkcs3_export_dh_params(const gnutls_datum * prime,
-				  const gnutls_datum * generator,
-				  gnutls_x509_crt_fmt format,
-				  unsigned char *params_data,
-				  int *params_data_size);
+	const gnutls_datum * generator, gnutls_x509_crt_fmt format,
+	unsigned char *params_data, int *params_data_size);
 
 /* get data from the session 
  */
 const gnutls_datum *gnutls_certificate_get_peers(gnutls_session,
-						 unsigned int *list_size);
+	unsigned int *list_size);
 const gnutls_datum *gnutls_certificate_get_ours(gnutls_session session);
 
 time_t gnutls_certificate_activation_time_peers(gnutls_session session);
@@ -603,17 +587,15 @@ int gnutls_certificate_client_get_request_status(gnutls_session);
 int gnutls_certificate_verify_peers(gnutls_session);
 
 int gnutls_pem_base64_encode(const char *header, const gnutls_datum * data,
-			     char *result, size_t * result_size);
+	char *result, size_t * result_size);
 int gnutls_pem_base64_decode(const char *header,
-			     const gnutls_datum * b64_data,
-			     unsigned char *result, size_t * result_size);
+	const gnutls_datum * b64_data,
+	unsigned char *result, size_t * result_size);
 
 int gnutls_pem_base64_encode_alloc(const char *header,
-				   const gnutls_datum * data,
-				   gnutls_datum * result);
+	const gnutls_datum * data, gnutls_datum * result);
 int gnutls_pem_base64_decode_alloc(const char *header,
-				   const gnutls_datum * b64_data,
-				   gnutls_datum * result);
+	const gnutls_datum * b64_data, gnutls_datum * result);
 
 /* key_usage will be an OR of the following values:
  */
@@ -760,6 +742,7 @@ int gnutls_pem_base64_decode_alloc(const char *header,
 
 #define GNUTLS_E_OPENPGP_KEYRING_ERROR -204
 #define GNUTLS_E_X509_UNSUPPORTED_OID -205
+#define GNUTLS_E_NAME_DOES_NOT_MATCH -206
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -1250
 
