@@ -1,24 +1,3 @@
-/*
- * Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
- * Copyright (C) 2004 Free Software Foundation
- *
- * This file is part of GNUTLS.
- *
- * GNUTLS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * GNUTLS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
- */
-
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -29,7 +8,6 @@
 #include <gnutls/openpgp.h>
 #include <time.h>
 #include <common.h>
-#include <pthread.h>
 
 #define TEST_STRING
 
@@ -43,8 +21,6 @@ static char buffer[5*1024];
 
 const char str_unknown[] = "(unknown)";
 
-pthread_mutex_t aMutex;
-
 static const char *my_ctime(const time_t * tv)
 {
 	static char buf[256];
@@ -93,7 +69,9 @@ void print_x509_info(gnutls_session session, const char* hostname)
 		    gnutls_x509_crt_import(crt, &cert_list[j],
 					   GNUTLS_X509_FMT_DER);
 		if (ret < 0) {
-			fprintf(stderr, "Decoding error: %s\n", gnutls_strerror(ret));
+			const char* str = gnutls_strerror(ret);
+			if (str == NULL) str = str_unknown;
+			fprintf(stderr, "Decoding error: %s\n", str);
 			return;
 		}
 
@@ -132,8 +110,10 @@ void print_x509_info(gnutls_session session, const char* hostname)
 
 			ret = gnutls_x509_crt_to_xml( crt, &xml_data, 0);
 			if (ret < 0) {
+				const char* str = gnutls_strerror(ret);
+				if (str == NULL) str = str_unknown;
 				fprintf(stderr, "XML encoding error: %s\n",
-					gnutls_strerror(ret));
+					str);
 				return;
 			}
 			
@@ -167,7 +147,9 @@ void print_x509_info(gnutls_session session, const char* hostname)
 			digest_size = sizeof(digest);
 			if ((ret=gnutls_x509_crt_get_fingerprint(crt, GNUTLS_DIG_MD5, digest, &digest_size))
 			    < 0) {
-			    	fprintf(stderr, "Error in fingerprint calculation: %s\n", gnutls_strerror(ret));
+				const char* str = gnutls_strerror(ret);
+				if (str == NULL) str = str_unknown;
+			    	fprintf(stderr, "Error in fingerprint calculation: %s\n", str);
 			} else {
 				print = printable;
 				for (i = 0; i < digest_size; i++) {
@@ -215,7 +197,7 @@ void print_x509_info(gnutls_session session, const char* hostname)
 
 }
 
-#ifdef USE_OPENPGP
+#ifdef HAVE_LIBOPENCDK
 
 void print_openpgp_info(gnutls_session session, const char* hostname)
 {
@@ -243,7 +225,9 @@ void print_openpgp_info(gnutls_session session, const char* hostname)
 		ret =
 		    gnutls_openpgp_key_import(crt, &cert_list[0], GNUTLS_OPENPGP_FMT_RAW);
 		if (ret < 0) {
-			fprintf(stderr, "Decoding error: %s\n", gnutls_strerror(ret));
+			const char* str = gnutls_strerror(ret);
+			if (str == NULL) str = str_unknown;
+			fprintf(stderr, "Decoding error: %s\n", str);
 			return;
 		}
 
@@ -278,8 +262,10 @@ void print_openpgp_info(gnutls_session session, const char* hostname)
 
 			ret = gnutls_openpgp_key_to_xml( crt, &xml_data, 0);
 			if (ret < 0) {
+				const char* str = gnutls_strerror(ret);
+				if (str == NULL) str = str_unknown;
 				fprintf(stderr, "XML encoding error: %s\n",
-					gnutls_strerror(ret));
+					str);
 				return;
 			}
 			
@@ -347,18 +333,11 @@ void print_openpgp_info(gnutls_session session, const char* hostname)
 
 void print_cert_vrfy(gnutls_session session)
 {
-//#define USE_THE_LOCK_LUKE
-#ifdef USE_THE_LOCK_LUKE
-	pthread_mutex_lock(&aMutex);
-#endif
 
 	int status;
 	status = gnutls_certificate_verify_peers(session);
 	printf("\n");
 
-#ifdef USE_THE_LOCK_LUKE
-	pthread_mutex_unlock(&aMutex);
-#endif
 	if (status == GNUTLS_E_NO_CERTIFICATE_FOUND) {
 		printf("- Peer did not send any certificate.\n");
 		return;
@@ -478,7 +457,7 @@ void print_cert_info(gnutls_session session, const char* hostname)
 		printf("X.509\n");
 		print_x509_info(session, hostname);
 		break;
-#ifdef USE_OPENPGP
+#ifdef HAVE_LIBOPENCDK
 	case GNUTLS_CRT_OPENPGP:
 		printf("OpenPGP\n");
 		print_openpgp_info(session, hostname);
@@ -525,26 +504,26 @@ void print_list(void)
 	printf(", ANON-DH\n");
 
 	printf("Compression methods:");
-	printf(" DEFLATE");
+	printf(" ZLIB");
 	printf(", LZO");
 	printf(", NULL\n");
 }
 
 void print_license(void)
 {
-fputs(	"\nCopyright (C) 2004 Free Software Foundation\n"
-	"This program is free software; you can redistribute it and/or modify \n"
-	"it under the terms of the GNU General Public License as published by \n"
-	"the Free Software Foundation; either version 2 of the License, or \n"
-	"(at your option) any later version. \n" "\n"
-	"This program is distributed in the hope that it will be useful, \n"
-	"but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
-	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
-	"GNU General Public License for more details. \n" "\n"
-	"You should have received a copy of the GNU General Public License \n"
-	"along with this program; if not, write to the Free Software \n"
-	"Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n",
-	stdout);
+	fprintf(stdout,
+		"\nCopyright (C) 2001-2003 Nikos Mavroyanopoulos\n"
+		"This program is free software; you can redistribute it and/or modify \n"
+		"it under the terms of the GNU General Public License as published by \n"
+		"the Free Software Foundation; either version 2 of the License, or \n"
+		"(at your option) any later version. \n" "\n"
+		"This program is distributed in the hope that it will be useful, \n"
+		"but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
+		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
+		"GNU General Public License for more details. \n" "\n"
+		"You should have received a copy of the GNU General Public License \n"
+		"along with this program; if not, write to the Free Software \n"
+		"Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n");
 }
 
 void parse_protocols(char **protocols, int protocols_size,
@@ -556,11 +535,10 @@ void parse_protocols(char **protocols, int protocols_size,
 		for (j = i = 0; i < protocols_size; i++) {
 			if (strncasecmp(protocols[i], "SSL", 3) == 0)
 				protocol_priority[j++] = GNUTLS_SSL3;
-			else if (strncasecmp(protocols[i], "TLS1.1", 6) == 0)
+			if (strncasecmp(protocols[i], "TLS1.1", 6) == 0)
 				protocol_priority[j++] = GNUTLS_TLS1_1;
-			else if (strncasecmp(protocols[i], "TLS", 3) == 0)
-				protocol_priority[j++] = GNUTLS_TLS1_0;
-			else fprintf(stderr, "Unknown protocol: '%s'\n", protocols[i]);
+			if (strncasecmp(protocols[i], "TLS1.0", 6) == 0)
+				protocol_priority[j++] = GNUTLS_TLS1;
 		}
 		protocol_priority[j] = 0;
 	}
@@ -575,18 +553,17 @@ void parse_ciphers(char **ciphers, int nciphers, int *cipher_priority)
 			if (strncasecmp(ciphers[i], "AES", 3) == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_AES_128_CBC;
-			else if (strncasecmp(ciphers[i], "3DE", 3) == 0)
+			if (strncasecmp(ciphers[i], "3DE", 3) == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_3DES_CBC;
-			else if (strcasecmp(ciphers[i], "ARCFOUR-40") == 0)
+			if (strcasecmp(ciphers[i], "ARCFOUR-40") == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_ARCFOUR_40;
-			else if (strcasecmp(ciphers[i], "ARCFOUR") == 0)
+			if (strcasecmp(ciphers[i], "ARCFOUR") == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_ARCFOUR_128;
-			else if (strncasecmp(ciphers[i], "NUL", 3) == 0)
+			if (strncasecmp(ciphers[i], "NUL", 3) == 0)
 				cipher_priority[j++] = GNUTLS_CIPHER_NULL;
-			else fprintf(stderr, "Unknown cipher: '%s'\n", ciphers[i]);
 		}
 		cipher_priority[j] = 0;
 	}
@@ -599,11 +576,10 @@ void parse_macs(char **macs, int nmacs, int *mac_priority)
 		for (j = i = 0; i < nmacs; i++) {
 			if (strncasecmp(macs[i], "MD5", 3) == 0)
 				mac_priority[j++] = GNUTLS_MAC_MD5;
-			else if (strncasecmp(macs[i], "RMD", 3) == 0)
+			if (strncasecmp(macs[i], "RMD", 3) == 0)
 				mac_priority[j++] = GNUTLS_MAC_RMD160;
-			else if (strncasecmp(macs[i], "SHA", 3) == 0)
+			if (strncasecmp(macs[i], "SHA", 3) == 0)
 				mac_priority[j++] = GNUTLS_MAC_SHA;
-			else fprintf(stderr, "Unknown MAC: '%s'\n", macs[i]);
 		}
 		mac_priority[j] = 0;
 	}
@@ -617,9 +593,8 @@ void parse_ctypes(char **ctype, int nctype, int *cert_type_priority)
 			if (strncasecmp(ctype[i], "OPE", 3) == 0)
 				cert_type_priority[j++] =
 				    GNUTLS_CRT_OPENPGP;
-			else if (strncasecmp(ctype[i], "X", 1) == 0)
+			if (strncasecmp(ctype[i], "X", 1) == 0)
 				cert_type_priority[j++] = GNUTLS_CRT_X509;
-			else fprintf(stderr, "Unknown certificate type: '%s'\n", ctype[i]);
 		}
 		cert_type_priority[j] = 0;
 	}
@@ -632,21 +607,20 @@ void parse_kx(char **kx, int nkx, int *kx_priority)
 		for (j = i = 0; i < nkx; i++) {
 			if (strcasecmp(kx[i], "SRP") == 0)
 				kx_priority[j++] = GNUTLS_KX_SRP;
-			else if (strcasecmp(kx[i], "SRP-RSA") == 0)
+			if (strcasecmp(kx[i], "SRP-RSA") == 0)
 				kx_priority[j++] = GNUTLS_KX_SRP_RSA;
-			else if (strcasecmp(kx[i], "SRP-DSS") == 0)
+			if (strcasecmp(kx[i], "SRP-DSS") == 0)
 				kx_priority[j++] = GNUTLS_KX_SRP_DSS;
-			else if (strcasecmp(kx[i], "RSA") == 0)
+			if (strcasecmp(kx[i], "RSA") == 0)
 				kx_priority[j++] = GNUTLS_KX_RSA;
-			else if (strcasecmp(kx[i], "RSA-EXPORT") == 0)
+			if (strcasecmp(kx[i], "RSA-EXPORT") == 0)
 				kx_priority[j++] = GNUTLS_KX_RSA_EXPORT;
-			else if (strncasecmp(kx[i], "DHE-RSA", 7) == 0)
+			if (strncasecmp(kx[i], "DHE-RSA", 7) == 0)
 				kx_priority[j++] = GNUTLS_KX_DHE_RSA;
-			else if (strncasecmp(kx[i], "DHE-DSS", 7) == 0)
+			if (strncasecmp(kx[i], "DHE-DSS", 7) == 0)
 				kx_priority[j++] = GNUTLS_KX_DHE_DSS;
-			else if (strncasecmp(kx[i], "ANON", 4) == 0)
+			if (strncasecmp(kx[i], "ANON", 4) == 0)
 				kx_priority[j++] = GNUTLS_KX_ANON_DH;
-			else fprintf(stderr, "Unknown key exchange: '%s'\n", kx[i]);
 		}
 		kx_priority[j] = 0;
 	}
@@ -659,13 +633,10 @@ void parse_comp(char **comp, int ncomp, int *comp_priority)
 		for (j = i = 0; i < ncomp; i++) {
 			if (strncasecmp(comp[i], "NUL", 3) == 0)
 				comp_priority[j++] = GNUTLS_COMP_NULL;
-			else if (strncasecmp(comp[i], "ZLI", 3) == 0)
-				comp_priority[j++] = GNUTLS_COMP_DEFLATE;
-			else if (strncasecmp(comp[i], "DEF", 3) == 0)
-				comp_priority[j++] = GNUTLS_COMP_DEFLATE;
-			else if (strncasecmp(comp[i], "LZO", 3) == 0)
+			if (strncasecmp(comp[i], "ZLI", 3) == 0)
+				comp_priority[j++] = GNUTLS_COMP_ZLIB;
+			if (strncasecmp(comp[i], "LZO", 3) == 0)
 				comp_priority[j++] = GNUTLS_COMP_LZO;
-			else fprintf(stderr, "Unknown compression: '%s'\n", comp[i]);
 		}
 		comp_priority[j] = 0;
 	}
@@ -689,11 +660,11 @@ char* ret;
 
 	ret = inet_ntoa( *((struct in_addr*)src));
 	
-	if (ret == NULL || strlen(ret) > cnt) {
+	if (strlen(ret) > cnt) {
 		return NULL;
 	}
 	strcpy( dst, ret);
-
+	
 	return dst;
 }
 #endif
