@@ -14,8 +14,10 @@ int test_sha( gnutls_session state);
 int test_rmd( gnutls_session state);
 int test_3des( gnutls_session state);
 int test_arcfour( gnutls_session state);
+int test_arcfour_40( gnutls_session state);
 int test_tls1( gnutls_session state);
-int test_tls1_2( gnutls_session state);
+int test_tls1_1( gnutls_session state);
+int test_tls_disable( gnutls_session state);
 int test_rsa_pms( gnutls_session state);
 int test_max_record_size( gnutls_session state);
 int test_version_rollback( gnutls_session state);
