@@ -80,6 +80,7 @@ typedef struct {
 } TLS_TEST;
 
 static const TLS_TEST tls_tests[] = {
+	{ "for TLS 1.1 support", test_tls1_1, "yes", "no", "dunno" },
 	{ "for TLS 1.0 support", test_tls1, "yes", "no", "dunno" },
 	{ "for SSL 3.0 support", test_ssl3, "yes", "no", "dunno" },
 	{ "for version rollback bug in RSA PMS", test_rsa_pms, "no", "yes", "dunno" },
@@ -87,7 +88,7 @@ static const TLS_TEST tls_tests[] = {
 
 	/* this test will disable TLS 1.0 if the server is 
 	 * buggy */
-	{ "whether we need to disable TLS 1.0", test_tls1_2, "no", "yes", "dunno" },
+	{ "whether we need to disable TLS 1.0", test_tls_disable, "no", "yes", "dunno" },
 
 	{ "whether the server ignores the RSA PMS version", test_rsa_pms_version_check, "yes", "no", "dunno"},
 	{ "whether the server can accept Hello Extensions", test_hello_extension, "yes", "no", "dunno"},
@@ -108,7 +109,8 @@ static const TLS_TEST tls_tests[] = {
 	{ "for ephemeral Diffie Hellman prime size", test_dhe_bits, "", "N/A", "N/A" },
 	{ "for AES cipher support (TLS extension)", test_aes, "yes", "no", "dunno"},
 	{ "for 3DES cipher support", test_3des, "yes", "no", "dunno"},
-	{ "for ARCFOUR cipher support", test_arcfour, "yes", "no", "dunno"},
+	{ "for ARCFOUR 128 cipher support", test_arcfour, "yes", "no", "dunno"},
+	{ "for ARCFOUR 40 cipher support", test_arcfour_40, "yes", "no", "dunno"},
 	{ "for MD5 MAC support", test_md5, "yes", "no", "dunno"},
 	{ "for SHA1 MAC support", test_sha, "yes", "no", "dunno"},
 	{ "for RIPEMD160 MAC support (TLS extension)", test_rmd, "yes", "no", "dunno"},
@@ -121,7 +123,7 @@ static const TLS_TEST tls_tests[] = {
 	{ "for SRP authentication support (TLS extension)", test_srp, "yes", "no", "dunno" },
 #endif
 	{ "for OpenPGP authentication support (TLS extension)", test_openpgp1, "yes", "no", "dunno" },
-	{ NULL }
+	{ NULL, NULL, NULL, NULL, NULL }
 };
 
 static int tt = 0;
